macro_rules! cli {
() => { ... };
($args:expr) => { ... };
}Expand description
A macro to create a CLI struct This macro will automatically set the name, version, about, and author from the environment variables at compile time
macro_rules! cli {
() => { ... };
($args:expr) => { ... };
}A macro to create a CLI struct This macro will automatically set the name, version, about, and author from the environment variables at compile time